==> nextcloud-jitsi-v0.16.2.tar.gz: jitsi/l10n/bg.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "конференции",
    "Jitsi Integration" : "Jitsi интеграция",
    "Conferences" : "Конференции",
    "Jitsi Integration (unofficial)" : "Jitsi интеграция (неофициална)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Това приложение интегрира конференции на приложението Jitsi в Nextcloud. \n\nХарактеристики:\n - 🎥 Лесни онлайн конференции в Nextcloud с помощта на Jitsi\n - 🔗 Връзки към конферентната зала за споделяне\n - 🔎 Показва конферентни стаи при глобалното търсене - \n✅ Тества системата преди да се присъедините към конференция\n\n Моля, прочетете [документацията](https://github.com/nextcloud/jitsi).",
    "Loading …" : "Зареждане …",
    "Server URL (required)" : "URL адрес на сървъра (нужно)",
    "Help link (optional)" : "Връзка за помощ (по избор)",
    "Display \"Join using the Jitsi app\"" : "Показване на „Присъединете се, като използвате приложението Jitsi“",
    "JWT Secret (optional)" : "JWT Тайна (по избор)",
    "JWT App ID" : "ИД на приложението JWT",
    "JWT Audience (optional)" : "JWT Аудитория (по избор)",
    "JWT Issuer (optional)" : "Издател на JWT (по избор)",
    "save" : "запиши",
    "saved" : "записан",
    "Saving …" : "Записване …",
    "Please provide a Jitsi instance URL" : "Моля, предоставете URL адрес на Jitsi екземпляр",
    "The server URL must start with https://" : "URL адресът на сървъра трябва да започва с https://",
    "It is highly recommended to set up a dedicated Jitsi instance" : "Силно се препоръчва да настроите специализиран Jitsi екземпляр",
    "Please provide the App ID" : "Моля, да предоставите ИД на приложението",
    "Failed to save settings" : "Неуспешно запазване на настройките",
    "Failed to load settings" : "Неуспешно зареждане на настройки",
    "Conference rooms" : "Конферентни стаи",
    "Conference" : "Конференция",
    "Conference left" : "Конференцията е напусната",
    "Problems detected" : "Открити са проблеми",
    "Your browser is non-optimal:" : "Вашият браузър е неоптимален:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Качеството на звука и видеото може да е лошо. Препоръчително е да използвате актуална версия на <b>Firefox/Chrome/Chromium</b>.",
    "Browser not supported" : "Браузърът не се поддържа",
    "Show system check" : "Показване на системна проверка",
    "Your name:" : "Вашето име:",
    "Click here to join" : "Щракнете тук, за да се присъедините",
    "Start muted" : "Започване с изключен звук",
    "Start with camera off" : "Започване с изключена камера",
    "Join with desktop app" : "Присъединете се към приложението за настолни компютри",
    "Join with mobile app" : "Присъединете се с мобилно приложение",
    "App button not working?" : "Бутонът на приложението не работи?",
    "Download the desktop app here ↗" : "Изтеглете приложението за настолни компютри тук ↗",
    "After successful installation try the button again." : "След успешно инсталиране, опитайте отново да натиснете бутона.",
    "Link copied" : "Връзката е копирана",
    "Cannot copy, please copy the link manually" : "Не може да се копира, моля, копирайте връзката ръчно",
    "Copy to clipboard" : "Копиране в клипборда",
    "Browser" : "Браузър",
    "non-optimal" : "неоптимален",
    "not supported" : "не се поддържа",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Качеството на звука и видеото може да е лошо. <br> Препоръчително е да използвате актуална версия на <b>Firefox/Chrome/Chromium</b>.",
    "Help" : "Помощ",
    "Camera" : "Камера",
    "Name of the new room" : "Име на новата стая",
    "No conference rooms yet" : "Все още няма конферентни стаи",
    "Create the first room:" : "Създайте първата стая:",
    "Microphone" : "Микрофон",
    "Join" : "Влез",
    "Delete room" : "Изтриване на стая",
    "Room not found" : "Стаята не е намерена ",
    "Please check the link/URL and ask your host" : "Моля, проверете връзката/URL адреса и попитайте вашия хост /сървър/",
    "Audio output" : "Аудио изход",
    "Play test sound" : "Възпроизвеждане на тестов звук",
    "System check" : "Проверка на системата",
    "Got issues?" : "Имате проблеми?",
    "Known problems / what you can try" : "Известни проблеми / какво можете да опитате",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Приемете правата за достъп до микрофон/камера в горната част на екрана",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Проверете правата за достъп до микрофона/камерата, като щракнете върху иконата до адресната лента. След това презаредете страницата.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• Ако имате DroidCam: Свържете се с мобилната камера, след което презаредете страницата",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Опитайте да се присъедините чрез приложението Jitsi (следвайте инструкциите в долната част на страницата)",
    "No camera/microphone access" : "Няма достъп до камера/микрофон",
    "Review your browser camera and microphone access settings" : "Прегледайте настройките за достъп до камера и микрофон на вашия браузър",
    "Click here for {browser} instructions" : "Щракнете тук за инструкции за {browser}",
    "Does not work?" : "Не работи?",
    "Click here for troubleshooting help" : "Щракнете тук за помощ при отстраняване на неизправности",
    "Conferences app not yet configured" : "Приложението за конференции все още не е конфигурирано",
    "Please contact your administrator to set up the conferences app." : "Моля, свържете се с вашия администратор, за да настроите приложението за конференции.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "Вашият браузър (%1$s) е остарял и вече не се поддържа",
    "It is recommended to use the latest version of one of the following browsers:" : "Препоръчително е да използвате най-новата версия на един от следните браузъри:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-jitsi-v0.18.0.tar.gz: jitsi/l10n/bg.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "конференции",
    "Jitsi Integration" : "Jitsi интеграция",
    "Conferences" : "Конференции",
    "Jitsi Integration (unofficial)" : "Jitsi интеграция (неофициална)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Това приложение интегрира конференции на приложението Jitsi в Nextcloud. \n\nХарактеристики:\n - 🎥 Лесни онлайн конференции в Nextcloud с помощта на Jitsi\n - 🔗 Връзки към конферентната зала за споделяне\n - 🔎 Показва конферентни стаи при глобалното търсене - \n✅ Тества системата преди да се присъедините към конференция\n\n Моля, прочетете [документацията](https://github.com/nextcloud/jitsi).",
    "Loading …" : "Зареждане …",
    "Server URL (required)" : "URL адрес на сървъра (нужно)",
    "Help link (optional)" : "Връзка за помощ (по избор)",
    "Display \"Join using the Jitsi app\"" : "Показване на „Присъединете се, като използвате приложението Jitsi“",
    "JWT Secret (optional)" : "JWT Тайна (по избор)",
    "JWT App ID" : "ИД на приложението JWT",
    "JWT Audience (optional)" : "JWT Аудитория (по избор)",
    "JWT Issuer (optional)" : "Издател на JWT (по избор)",
    "save" : "запиши",
    "saved" : "записан",
    "Saving …" : "Записване …",
    "Please provide a Jitsi instance URL" : "Моля, предоставете URL адрес на Jitsi екземпляр",
    "The server URL must start with https://" : "URL адресът на сървъра трябва да започва с https://",
    "It is highly recommended to set up a dedicated Jitsi instance" : "Силно се препоръчва да настроите специализиран Jitsi екземпляр",
    "Please provide the App ID" : "Моля, да предоставите ИД на приложението",
    "Failed to save settings" : "Неуспешно запазване на настройките",
    "Failed to load settings" : "Неуспешно зареждане на настройки",
    "Conference rooms" : "Конферентни стаи",
    "Conference" : "Конференция",
    "Conference left" : "Конференцията е напусната",
    "Problems detected" : "Открити са проблеми",
    "Your browser is non-optimal:" : "Вашият браузър е неоптимален:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Качеството на звука и видеото може да е лошо. Препоръчително е да използвате актуална версия на <b>Firefox/Chrome/Chromium</b>.",
    "Browser not supported" : "Браузърът не се поддържа",
    "Show system check" : "Показване на системна проверка",
    "Your name:" : "Вашето име:",
    "Click here to join" : "Кликнете тук, за да се присъедините",
    "Start muted" : "Започване с изключен звук",
    "Start with camera off" : "Започване с изключена камера",
    "Join with desktop app" : "Присъединете се към приложението за настолни компютри",
    "Join with mobile app" : "Присъединете се с мобилно приложение",
    "App button not working?" : "Бутонът на приложението не работи?",
    "Download the desktop app here ↗" : "Изтеглете приложението за настолни компютри тук ↗",
    "The mobile app is available via the app store of your choice." : "Мобилното приложение е достъпно в  магазин за приложения по ваш избор.",
    "After successful installation try the button again." : "След успешно инсталиране, опитайте отново да натиснете бутона.",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "Все още не работи? Копирайте връзката по-долу и я поставете в полето за въвеждане на началния екран на приложението Jitsi.",
    "Link copied" : "Връзката е копирана",
    "Cannot copy, please copy the link manually" : "Не може да се копира, моля, копирайте връзката ръчно",
    "Copy to clipboard" : "Копиране в клипборда",
    "Browser" : "Браузър",
    "non-optimal" : "неоптимален",
    "not supported" : "не се поддържа",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Качеството на звука и видеото може да е лошо. <br> Препоръчително е да използвате актуална версия на <b>Firefox/Chrome/Chromium</b>.",
    "Help" : "Помощ",
    "Camera" : "Камера",
    "Name of the new room" : "Име на новата стая",
    "No conference rooms yet" : "Все още няма конферентни стаи",
    "Create the first room:" : "Създайте първата стая:",
    "Microphone" : "Микрофон",
    "Join" : "Влез",
    "Delete room" : "Изтриване на стая",
    "Room not found" : "Стаята не е намерена ",
    "Please check the link/URL and ask your host" : "Моля, проверете връзката/URL адреса и попитайте вашия хост /сървър/",
    "Audio output" : "Аудио изход",
    "Play test sound" : "Възпроизвеждане на тестов звук",
    "System check" : "Проверка на системата",
    "Got issues?" : "Имате проблеми?",
    "Known problems / what you can try" : "Известни проблеми / какво можете да опитате",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Приемете правата за достъп до микрофон/камера в горната част на екрана",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Проверете правата за достъп до микрофона/камерата, като щракнете върху иконата до адресната лента. След това презаредете страницата.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• Ако имате DroidCam: Свържете се с мобилната камера, след което презаредете страницата",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Опитайте да се присъедините чрез приложението Jitsi (следвайте инструкциите в долната част на страницата)",
    "No camera/microphone access" : "Няма достъп до камера/микрофон",
    "Review your browser camera and microphone access settings" : "Прегледайте настройките за достъп до камера и микрофон на вашия браузър",
    "Click here for {browser} instructions" : "Щракнете тук за инструкции за {browser}",
    "Does not work?" : "Не работи?",
    "Click here for troubleshooting help" : "Щракнете тук за помощ при отстраняване на неизправности",
    "Conferences app not yet configured" : "Приложението за конференции все още не е конфигурирано",
    "Please contact your administrator to set up the conferences app." : "Моля, свържете се с вашия администратор, за да настроите приложението за конференции.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "Вашият браузър (%1$s) е остарял и вече не се поддържа",
    "It is recommended to use the latest version of one of the following browsers:" : "Препоръчително е да използвате най-новата версия на един от следните браузъри:"
},
"nplurals=2; plural=(n != 1);");
